@@ -21,6 +21,8 @@
  *
  *****************************************************************************/
 
+#include "config.h"
+
 #define MOD_GM_NEB  /**< set mod_gearman neb features */
 #define NSCORE      /**< enable core features         */
 
@@ -33,8 +35,6 @@
 #include <unistd.h>
 #include <pthread.h>
 
-#define GM_PERFDATA_QUEUE    "perfdata"  /**< default performance data queue */
-
 /** @file
  *  @brief Mod-Gearman NEB Module
  *  @addtogroup mod_gearman_neb_module NEB Module
@@ -50,8 +50,27 @@
  * @{
  */
 
+/* include some Nagios stuff as well */
+#ifdef USENAGIOS3
+#include "nagios3/nagios.h"
+#include "nagios3/neberrors.h"
+#include "nagios3/nebstructs.h"
+#include "nagios3/nebcallbacks.h"
+#include "nagios3/broker.h"
+#include "nagios3/macros.h"
+#endif
+#ifdef USENAGIOS4
+#include "nagios4/nagios.h"
+#include "nagios4/neberrors.h"
+#include "nagios4/nebstructs.h"
+#include "nagios4/nebcallbacks.h"
+#include "nagios4/broker.h"
+#include "nagios4/macros.h"
+#endif
+#ifdef USENAEMON
 /* include naemon */
 #include "naemon/naemon.h"
+#endif
 
 /* include the gearman libs */
 #include <libgearman/gearman.h>
@@ -87,6 +106,15 @@ int nebmodule_deinit( int flags, int reason );
  */
 void mod_gm_add_result_to_list(check_result * newcheckresult);
 
+/** wraps the nm_log / write_to_all_logs core logger
+ *
+ * @param[in] type - type of the log event
+ * @param[in] data - actual text to log
+ *
+ * @return nothing
+ */
+void log_core(int type, char *data);
+
 /**
  * @}
  */
